==> PaymentMadeSimple1.3.zip: PaymentMadeSimple/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: Payment Made Simple - A module for handling payments with CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/pms/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

$db =& $gCms->GetDb();
$dict = NewDataDictionary( $db );

// Remove the database tables
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_pms_gateways" );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix()."module_pms_gwattributes" );
$dict->ExecuteSQLArray($sqlarray);

// Remove the sequences
$db->DropSequence( cms_db_prefix()."module_pms_gateways_seq" );
$db->DropSequence( cms_db_prefix()."module_pms_gwattributes_seq" );

// Remove the permissions
$this->RemovePermission('Use PaymentMadeSimple');
$this->RemovePermission('Modify PaymentMadeSimple');

// Remove all the preferences
$this->RemovePreference();

// And all Templates
$this->DeleteTemplate();

// remove the event
#$this->RemoveEvent( 'OnPMSPreferenceChange' );

// Put mention into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled'));

?>

==> PaymentMadeSimple-1.6.zip: PaymentMadeSimple/method.uninstall.php <==
<?php
#-------------------------------------------------------------------------
# Module: Payment Made Simple - A module for handling payments with CMS - CMS Made Simple
# Copyright (c) 2008 by Duketown
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2005 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/pms/
#
#-------------------------------------------------------------------------
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
# Or read it online: http://www.gnu.org/licenses/licenses.html#GPL
#
#-------------------------------------------------------------------------

$gCms = cmsms(); if( !is_object($gCms) ) exit;
$db = cmsms()->GetDb();
$dict = NewDataDictionary( $db );

// Remove the database tables
$sqlarray = $dict->DropTableSQL( cms_db_prefix().'module_pms_gateways' );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix().'module_pms_gwattributes' );
$dict->ExecuteSQLArray($sqlarray);
$sqlarray = $dict->DropTableSQL( cms_db_prefix().'module_pms_payments' );
$dict->ExecuteSQLArray($sqlarray);

// Remove the sequences
$db->DropSequence( cms_db_prefix().'module_pms_gateways_seq' );
$db->DropSequence( cms_db_prefix().'module_pms_gwattributes_seq' );
$db->DropSequence( cms_db_prefix().'module_pms_payments_seq' );

// Remove the permissions
$this->RemovePermission('Use PaymentMadeSimple');
$this->RemovePermission('Modify PaymentMadeSimple');

// Remove all the preferences
$this->RemovePreference();

// And all Templates
$this->DeleteTemplate();

// remove the event
#$this->RemoveEvent( 'OnPMSPreferenceChange' );

// Log that module has been uninstalled into the admin log
$this->Audit( 0, $this->Lang('friendlyname'), $this->Lang('uninstalled'));

?>
